==> open_watcom_1.5.0-src.zip: bld/aui/c/wndalloc.c <==
/****************************************************************************
*
*                            Open Watcom Project
*
*    Portions Copyright (c) 1983-2002 Sybase, Inc. All Rights Reserved.
*
*  ========================================================================
*
*    This file contains Original Code and/or Modifications of Original
*    Code as defined in and that are subject to the Sybase Open Watcom
*    Public License version 1.0 (the 'License'). You may not use this file
*    except in compliance with the License. BY USING THIS FILE YOU AGREE TO
*    ALL TERMS AND CONDITIONS OF THE LICENSE. A copy of the License is
*    provided with the Original Code and Modifications, and is also
*    available at www.sybase.com/developer/opensource.
*
*    The Original Code and all software distributed under the License are
*    distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
*    EXPRESS OR IMPLIED, AND SYBASE AND ALL CONTRIBUTORS HEREBY DISCLAIM
*    ALL SUCH WARRANTIES, INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF
*    MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR
*    NON-INFRINGEMENT. Please see the License for the specific language
*    governing rights and limitations under the License.
*
*  ========================================================================
*
* Description:  WHEN YOU FIGURE OUT WHAT THIS MODULE DOES, PLEASE
*               DESCRIBE IT HERE!
*
****************************************************************************/


#include "auipvt.h"
#include <malloc.h>
#include <stdlib.h>
#include <stdio.h>

/*
 * The app should replace this module
 */
void    WndNoMemory()
{
    Say( "No memory for window\n" );
    exit( 1 );
}


extern void *   WndAlloc( unsigned size )
{
    return( malloc( size ) );
}


extern void *   WndRealloc( void *chunk, unsigned size )
{
    return( realloc( chunk, size ) );
}


void    WndFree( void *chunk )
{
    free( chunk );
}

void WndMemInit()
{
}

void WndMemFini()
{
}

==> open_watcom_1.7.0-src.zip: bld/aui/c/wndalloc.c <==
/****************************************************************************
*
*                            Open Watcom Project
*
*    Portions Copyright (c) 1983-2002 Sybase, Inc. All Rights Reserved.
*
*  ========================================================================
*
*    This file contains Original Code and/or Modifications of Original
*    Code as defined in and that are subject to the Sybase Open Watcom
*    Public License version 1.0 (the 'License'). You may not use this file
*    except in compliance with the License. BY USING THIS FILE YOU AGREE TO
*    ALL TERMS AND CONDITIONS OF THE LICENSE. A copy of the License is
*    provided with the Original Code and Modifications, and is also
*    available at www.sybase.com/developer/opensource.
*
*    The Original Code and all software distributed under the License are
*    distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
*    EXPRESS OR IMPLIED, AND SYBASE AND ALL CONTRIBUTORS HEREBY DISCLAIM
*    ALL SUCH WARRANTIES, INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF
*    MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR
*    NON-INFRINGEMENT. Please see the License for the specific language
*    governing rights and limitations under the License.
*
*  ========================================================================
*
* Description:  Default memory management routines.
*
****************************************************************************/


#include "auipvt.h"
#include <stdlib.h>
#include <stdio.h>

/*
 * The app should replace this module
 */
void    WndNoMemory( void )
{
    Say( "No memory for window\n" );
    exit( 1 );
}


extern void *   WndAlloc( unsigned size )
{
    return( malloc( size ) );
}


extern void *   WndRealloc( void *chunk, unsigned size )
{
    return( realloc( chunk, size ) );
}


void    WndFree( void *chunk )
{
    free( chunk );
}

void WndMemInit( void )
{
}

void WndMemFini( void )
{
}
